#!/bin/sh
#
#  COPYRIGHT (C) 2006 MITSUBISHI ELECTRIC CORPORATION
#  ALL RIGHTS RESERVED
#
#  Uninstall Printer Driver Script
#  For MITSUBISHI CP9550D/DW Digital Color Printer
#


TARGET_DIR_VENDOR="MITSUBISHI"
TARGET_DIR_ICONS="Icons"
TARGET_DIR_FILTER="filter"
TARGET_KEXT="CP9550.kext"
TARGET_USBCLASSDIRVER="CP9550.plugin"
TARGET_PPD="CP9550.ppd.gz"
TARGET_ICON="CP9550.icns"
TARGET_FILTER="CP9550Filter"
TARGET_PKG="CP9550MacOSX.pkg"

rm_printer() {
    for model in $*
    do
      /usr/sbin/lpadmin -x $model 2> /dev/null
    done
    return 0
}

remove_file() {
    for file in $*
    do
        if [ -f "$file" ]; then
            sudo rm -f "$file"
            if [ $? != 0 ]; then
                return 1
            fi
        fi
    done
    return 0
}

remove_dir() {
    if [ -d "$*" ]; then
        sudo rm -rf "$*"
        if [ $? != 0 ]; then
            return 1
        fi
    fi
    return 0
}

remove_emptydir() {
    if [ -d $* ]; then
        local isEmpty=1
        for file in $(ls "$*"); do
            local isEmpty=0
            break
        done
        if [ $isEmpty = 1 ]; then
            sudo rm -rf "$*"
            if [ $? != 0 ]; then
                return 1
            fi
        fi
    fi
    return 0
}

remove_driver() {
    if remove_dir "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_USBCLASSDIRVER"; then :; else
        return 1
    fi
    if remove_file $(find /Library/Printers/PPDs -name "$TARGET_PPD"); then :; else
        return 1
    fi
    if remove_file "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_ICONS/$TARGET_ICON"; then :; else
        return 1
    fi
    if remove_emptydir "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_ICONS"; then :; else
        return 1
    fi
    if remove_file "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_FILTER/$TARGET_FILTER"; then :; else
        return 1
    fi
    if remove_emptydir "/Library/Printers/$TARGET_DIR_VENDOR/$TARGET_DIR_FILTER"; then :; else
        return 1
    fi
    if remove_emptydir "/Library/Printers/$TARGET_DIR_VENDOR"; then :; else
        return 1
    fi
    if remove_dir "/Library/Receipts/$TARGET_PKG"; then :; else
        return 1
    fi
    if remove_dir "/System/Library/Extensions/$TARGET_KEXT"; then :; else
        return 1
    fi
    if remove_file "/System/Library/Extensions.mkext"; then :; else
        return 0
    fi
    if remove_file "/System/Library/Extensions.kextcache"; then :; else
        return 0
    fi

    return 0
}

do_reboot() {
    echo "Uninstallation was completed."

    while true
    do
        echo -n "Is a computer rebooted?(Y/N): "
        read isReboot

        case "$isReboot" in
            "y" | "Y" )
                osascript -e 'tell application "System Events"' -e 'restart' -e 'end tell'
                break;;
            "n" | "N" )
                break;;
            * )
                ;;
        esac
    done
    return 0
}

rm_printer $(find /etc/cups/ppd -name "CP9550D_*.ppd" -exec basename {} .ppd \;)
if remove_driver; then
    do_reboot
else
    echo "Uninstallation went wrong."
fi

exit 0
